"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const apollo_cache_inmemory_1 = require("apollo-cache-inmemory");
const apollo_client_1 = require("apollo-client");
const chai_1 = require("chai");
const graphql_1 = require("graphql");
const sinon_1 = __importDefault(require("sinon"));
const slicknode_client_1 = __importDefault(require("slicknode-client"));
const index_1 = __importDefault(require("../index"));
describe('SlicknodeLink', () => {
    it('fails for missing configuration options', () => {
        chai_1.expect(() => {
            const link = new index_1.default({
                client: null,
            });
        }).to.throw('No instance of a client provided in configuration options for SlicknodeLink');
    });
    it('creates link successfully', () => {
        const client = new slicknode_client_1.default({
            endpoint: 'https://localhost',
        });
        const link = new index_1.default({
            client,
        });
        chai_1.expect(link).to.not.equal(null);
    });
    it('sends and receives requests with apollo client', () => __awaiter(this, void 0, void 0, function* () {
        const client = new slicknode_client_1.default({
            endpoint: 'https://localhost',
        });
        const link = new index_1.default({
            client,
        });
        const payload = {
            data: {
                value: 'test',
            },
        };
        sinon_1.default.stub(client, 'fetch').resolves(payload);
        const apolloClient = new apollo_client_1.ApolloClient({
            link,
            cache: new apollo_cache_inmemory_1.InMemoryCache(),
        });
        const result = yield apolloClient.query({
            query: graphql_1.parse('{value}'),
        });
        chai_1.expect(result.data).to.deep.equal(payload.data);
    }));
    it('handles error with apollo client', () => __awaiter(this, void 0, void 0, function* () {
        const client = new slicknode_client_1.default({
            endpoint: 'https://localhost',
        });
        const link = new index_1.default({
            client,
        });
        const errorMessage = 'Error fetching data';
        sinon_1.default.stub(client, 'fetch').throws(errorMessage);
        const apolloClient = new apollo_client_1.ApolloClient({
            link,
            cache: new apollo_cache_inmemory_1.InMemoryCache(),
        });
        try {
            const result = yield apolloClient.query({
                query: graphql_1.parse('{value}'),
            });
        }
        catch (e) {
            chai_1.expect(e.networkError.name).to.deep.equal(errorMessage);
        }
    }));
});
//# sourceMappingURL=index-test.js.map