"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const apollo_link_1 = require("apollo-link");
const printer_1 = require("graphql/language/printer");
/**
 * Creates an ApolloLink instance to be used with apollo-client
 * @param {IOptions} options
 * @returns {ApolloLink}
 */
function createLink(options) {
    const client = options.client;
    if (!client) {
        throw new Error('No instance of a client provided in configuration options for SlicknodeLink');
    }
    return new apollo_link_1.ApolloLink((operation) => new apollo_link_1.Observable((observer) => {
        const { operationName, variables, query, } = operation;
        const queryString = printer_1.print(query);
        // $FlowFixMe: client is always defined
        client.fetch(queryString, variables, operationName)
            .then((result) => {
            observer.next(result);
            observer.complete();
            return result;
        })
            .catch((err) => {
            // fetch was cancelled so its already been cleaned up in the unsubscribe
            // if (err.name === 'AbortError') return;
            observer.error(err);
        });
    }));
}
/**
 * SlicknodeLink instance to be used to load data with apollo-client
 * from slicknode GraphQL servers
 */
class SlicknodeLink extends apollo_link_1.ApolloLink {
    constructor(options) {
        const link = createLink(options);
        super(link.request);
    }
}
exports.default = SlicknodeLink;
//# sourceMappingURL=index.js.map